@@ -12,6 +12,7 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDir>
+#include <QIcon>
 #include <QQuickStyle>
 #include <QUrl>
 
@@ -20,6 +21,8 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 
+#include "fileTree.h"
+
 int main(int argc, char *argv[])
 {
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
@@ -31,6 +34,9 @@ int main(int argc, char *argv[])
 #endif
     QApplication app(argc, argv);
 
+    qRegisterMetaType<std::shared_ptr<File>>("std::shared_ptr<File>");
+    qRegisterMetaType<std::shared_ptr<Folder>>("std::shared_ptr<Folder>");
+
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
